<div align="center">

<img width=300 src="https://github.com/checktheroads/hyperglass/blob/master/logo.png"/>

<hr>

**The hyperglass agent is a RESTful API agent for [hyperglass](https://github.com/checktheroads/hyperglass), currently supporting:**

### [Free Range Routing](https://frrouting.org/)
### [BIRD Routing Daemon](https://bird.network.cz/)

</div>

# Installation

### [Check out the docs](https://hyperglass.io/docs/agent)

# License

[Clear BSD License](https://github.com/checktheroads/hyperglass-agent/master/LICENSE)
